[haiku-development] Re: Color_Space -> B_RGBA32_BIG bug

  • From: Ralf Schuelke <teammaui@xxxxxx>
  • To: haiku-development@xxxxxxxxxxxxx
  • Date: Fri, 15 Aug 2008 19:52:40 +0200

Hi,
here is a litel patch to fix it in time, i found in Bitmap.cpp a answer.
I hope it is so OK.

-- 
Ralf Schülke aka Stargater
Index: Bitmap.cpp
===================================================================
--- Bitmap.cpp  (revision 26962)
+++ Bitmap.cpp  (working copy)
@@ -574,8 +574,8 @@
        int32 inBPR = -1;
        // tweaks to mimic R5 behavior
        if (error == B_OK) {
-               // B_RGB32 means actually unpadded B_RGB24_BIG
-               if (colorSpace == B_RGB32) {
+               // B_RGB32 and B_RGB32_BIG means actually unpadded B_RGB24_BIG
+               if (colorSpace == B_RGB32 || colorSpace == B_RGB32_BIG) {
                        colorSpace = B_RGB24_BIG;
                        inBPR = width * 3;
                // If in color space is B_CMAP8, but the bitmap's is another 
one,

Other related posts: